.. module:: itsdangerous.exc

Exceptions
==========

.. autoexception:: BadData
    :members:

.. autoexception:: BadSignature
    :members:

.. autoexception:: BadTimeSignature
    :members:

.. autoexception:: SignatureExpired
    :members:

.. autoexception:: BadHeader
    :members:

.. autoexception:: BadPayload
    :members:
